# Ceramic

Types:

```python
from ceramic_ai.types import SearchResponse
```

Methods:

- <code title="post /search">client.<a href="./src/ceramic_ai/_client.py">search</a>(\*\*<a href="src/ceramic_ai/types/client_search_params.py">params</a>) -> <a href="./src/ceramic_ai/types/search_response.py">SearchResponse</a></code>
